==> haskell-openpgp-asciiarmor-0.1.2-220-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-JR6fOCrsYnzDzVpnNLA1ym
key:                  openpgp-asciiarmor-0.1.2-JR6fOCrsYnzDzVpnNLA1ym
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  26fe639c884f81b46fcceaa6916ec037
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-JR6fOCrsYnzDzVpnNLA1ym
depends:
    attoparsec-0.14.4-10U3JVdOf0KJjxjEqAIrEh base-4.15.1.0
    base64-bytestring-1.2.1.0-88nOz7AP8GEI61ac5Ca3UI binary-0.8.8.0
    bytestring-0.10.12.1

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.2-223-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 openpgp-asciiarmor
version:              0.1.2
visibility:           public
id:                   openpgp-asciiarmor-0.1.2-LMdClgDu1Re5XayBODpfUx
key:                  openpgp-asciiarmor-0.1.2-LMdClgDu1Re5XayBODpfUx
license:              MIT
copyright:            2012-2019 Clint Adams
maintainer:           Clint Adams <clint@debian.org>
author:               Clint Adams
homepage:             http://floss.scru.org/openpgp-asciiarmor
synopsis:             OpenPGP (RFC4880) ASCII Armor codec
description:          OpenPGP (RFC4880) ASCII Armor codec
category:             Codec, Data
abi:                  0b13ac50dc1f00cb5dea19ca3b9ca37a
exposed:              True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types

hidden-modules:
    Data.Digest.CRC24 Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
    Codec.Encryption.OpenPGP.ASCIIArmor.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/openpgp-asciiarmor-0.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/openpgp-asciiarmor-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-openpgp-asciiarmor
hs-libraries:         HSopenpgp-asciiarmor-0.1.2-LMdClgDu1Re5XayBODpfUx
depends:
    attoparsec-0.14.4-IunVluIlg1j8NQqYaVddnF base-4.15.1.0
    base64-bytestring-1.2.1.0-CM0hYSNUcmEXJNyTXmK7o binary-0.8.8.0
    bytestring-0.10.12.1

haddock-interfaces:
    /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock

haddock-html:         /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
